==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/RuntimeEnvironment.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin

import com.pulumi.azurenative.automation.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.automation.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [RuntimeEnvironment].
 */
@PulumiTagMarker
public class RuntimeEnvironmentResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: RuntimeEnvironmentArgs = RuntimeEnvironmentArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend RuntimeEnvironmentArgsBuilder.() -> Unit) {
        val builder = RuntimeEnvironmentArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): RuntimeEnvironment {
        val builtJavaResource =
            com.pulumi.azurenative.automation.RuntimeEnvironment(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return RuntimeEnvironment(builtJavaResource)
    }
}

/**
 * Definition of the Runtime Environment type.
 * Azure REST API version: 2023-05-15-preview.
 * ## Example Usage
 * ### Create or update automation account
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var runtimeEnvironment = new AzureNative.Automation.RuntimeEnvironment("runtimeEnvironment", new()
 *     {
 *         AutomationAccountName = "myAutomationAccount9",
 *         DefaultPackages =
 *         {
 *             { "Az", "6.*" },
 *         },
 *         Language = "PowerShell",
 *         Location = "East US 2",
 *         ResourceGroupName = "rg",
 *         RuntimeEnvironmentName = "myRuntimeEnvironmentName",
 *         Version = "7.1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/automation/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := automation.NewRuntimeEnvironment(ctx, "runtimeEnvironment", &automation.RuntimeEnvironmentArgs{
 * 			AutomationAccountName: pulumi.String("myAutomationAccount9"),
 * 			DefaultPackages: pulumi.StringMap{
 * 				"Az": pulumi.String("6.*"),
 * 			},
 * 			Language:               pulumi.String("PowerShell"),
 * 			Location:               pulumi.String("East US 2"),
 * 			ResourceGroupName:      pulumi.String("rg"),
 * 			RuntimeEnvironmentName: pulumi.String("myRuntimeEnvironmentName"),
 * 			Version:                pulumi.String("7.1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.automation.RuntimeEnvironment;
 * import com.pulumi.azurenative.automation.RuntimeEnvironmentArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var runtimeEnvironment = new RuntimeEnvironment("runtimeEnvironment", RuntimeEnvironmentArgs.builder()
 *             .automationAccountName("myAutomationAccount9")
 *             .defaultPackages(Map.of("Az", "6.*"))
 *             .language("PowerShell")
 *             .location("East US 2")
 *             .resourceGroupName("rg")
 *             .runtimeEnvironmentName("myRuntimeEnvironmentName")
 *             .version("7.1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:automation:RuntimeEnvironment myRuntimeEnvironmentName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Automation/automationAccounts/{automationAccountName}/runtimeEnvironments/{runtimeEnvironmentName}
 * ```
 */
public class RuntimeEnvironment internal constructor(
    override val javaResource: com.pulumi.azurenative.automation.RuntimeEnvironment,
) : KotlinCustomResource(javaResource, RuntimeEnvironmentMapper) {
    /**
     * List of Default packages for Environment
     */
    public val defaultPackages: Output<Map<String, String>>?
        get() = javaResource.defaultPackages().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0.key.to(args0.value) }).toMap()
            }).orElse(null)
        })

    /**
     * Gets or sets the description.
     */
    public val description: Output<String>?
        get() = javaResource.description().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Language of Runtime Environment
     */
    public val language: Output<String>?
        get() = javaResource.language().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })

    /**
     * Version of Language
     */
    public val version: Output<String>?
        get() = javaResource.version().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })
}

public object RuntimeEnvironmentMapper : ResourceMapper<RuntimeEnvironment> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.automation.RuntimeEnvironment::class == javaResource::class

    override fun map(javaResource: Resource): RuntimeEnvironment = RuntimeEnvironment(
        javaResource as
            com.pulumi.azurenative.automation.RuntimeEnvironment,
    )
}

/**
 * @see [RuntimeEnvironment].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [RuntimeEnvironment].
 */
public suspend fun runtimeEnvironment(
    name: String,
    block: suspend RuntimeEnvironmentResourceBuilder.() -> Unit,
): RuntimeEnvironment {
    val builder = RuntimeEnvironmentResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [RuntimeEnvironment].
 * @param name The _unique_ name of the resulting resource.
 */
public fun runtimeEnvironment(name: String): RuntimeEnvironment {
    val builder = RuntimeEnvironmentResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/RuntimeEnvironment.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin

import com.pulumi.azurenative.automation.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.automation.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [RuntimeEnvironment].
 */
@PulumiTagMarker
public class RuntimeEnvironmentResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: RuntimeEnvironmentArgs = RuntimeEnvironmentArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend RuntimeEnvironmentArgsBuilder.() -> Unit) {
        val builder = RuntimeEnvironmentArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): RuntimeEnvironment {
        val builtJavaResource =
            com.pulumi.azurenative.automation.RuntimeEnvironment(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return RuntimeEnvironment(builtJavaResource)
    }
}

/**
 * Definition of the Runtime Environment type.
 * Azure REST API version: 2023-05-15-preview.
 * ## Example Usage
 * ### Create or update automation account
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var runtimeEnvironment = new AzureNative.Automation.RuntimeEnvironment("runtimeEnvironment", new()
 *     {
 *         AutomationAccountName = "myAutomationAccount9",
 *         DefaultPackages =
 *         {
 *             { "Az", "8.3.0" },
 *         },
 *         Language = "PowerShell",
 *         Location = "East US 2",
 *         ResourceGroupName = "rg",
 *         RuntimeEnvironmentName = "myRuntimeEnvironmentName",
 *         Version = "7.1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/automation/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := automation.NewRuntimeEnvironment(ctx, "runtimeEnvironment", &automation.RuntimeEnvironmentArgs{
 * 			AutomationAccountName: pulumi.String("myAutomationAccount9"),
 * 			DefaultPackages: pulumi.StringMap{
 * 				"Az": pulumi.String("8.3.0"),
 * 			},
 * 			Language:               pulumi.String("PowerShell"),
 * 			Location:               pulumi.String("East US 2"),
 * 			ResourceGroupName:      pulumi.String("rg"),
 * 			RuntimeEnvironmentName: pulumi.String("myRuntimeEnvironmentName"),
 * 			Version:                pulumi.String("7.1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.automation.RuntimeEnvironment;
 * import com.pulumi.azurenative.automation.RuntimeEnvironmentArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var runtimeEnvironment = new RuntimeEnvironment("runtimeEnvironment", RuntimeEnvironmentArgs.builder()
 *             .automationAccountName("myAutomationAccount9")
 *             .defaultPackages(Map.of("Az", "8.3.0"))
 *             .language("PowerShell")
 *             .location("East US 2")
 *             .resourceGroupName("rg")
 *             .runtimeEnvironmentName("myRuntimeEnvironmentName")
 *             .version("7.1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:automation:RuntimeEnvironment myRuntimeEnvironmentName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Automation/automationAccounts/{automationAccountName}/runtimeEnvironments/{runtimeEnvironmentName}
 * ```
 */
public class RuntimeEnvironment internal constructor(
    override val javaResource: com.pulumi.azurenative.automation.RuntimeEnvironment,
) : KotlinCustomResource(javaResource, RuntimeEnvironmentMapper) {
    /**
     * List of Default packages for Environment
     */
    public val defaultPackages: Output<Map<String, String>>?
        get() = javaResource.defaultPackages().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0.key.to(args0.value) }).toMap()
            }).orElse(null)
        })

    /**
     * Gets or sets the description.
     */
    public val description: Output<String>?
        get() = javaResource.description().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Language of Runtime Environment
     */
    public val language: Output<String>?
        get() = javaResource.language().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })

    /**
     * Version of Language
     */
    public val version: Output<String>?
        get() = javaResource.version().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })
}

public object RuntimeEnvironmentMapper : ResourceMapper<RuntimeEnvironment> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.automation.RuntimeEnvironment::class == javaResource::class

    override fun map(javaResource: Resource): RuntimeEnvironment = RuntimeEnvironment(
        javaResource as
            com.pulumi.azurenative.automation.RuntimeEnvironment,
    )
}

/**
 * @see [RuntimeEnvironment].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [RuntimeEnvironment].
 */
public suspend fun runtimeEnvironment(
    name: String,
    block: suspend RuntimeEnvironmentResourceBuilder.() -> Unit,
): RuntimeEnvironment {
    val builder = RuntimeEnvironmentResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [RuntimeEnvironment].
 * @param name The _unique_ name of the resulting resource.
 */
public fun runtimeEnvironment(name: String): RuntimeEnvironment {
    val builder = RuntimeEnvironmentResourceBuilder()
    builder.name(name)
    return builder.build()
}
